==> dl.php?src=linea21_1_7.zip: linea21/languages/fr/lang_theme.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	confirmation
 *  	*/
$lang['theme']['name']="thème";
$lang['theme']['confirm_add'] = "Ajout du thème réalisé avec succès\n";
$lang['theme']['confirm_mod'] = "Modification du thème réalisée avec succès\n";
$lang['theme']['confirm_sup'] ="Suppression du thème réalisée avec succès\n";

/*	nommage rubrique add / mod /det
 *  	*/
$lang['theme']['add_title']="Saisie des informations du nouveau ".$lang['theme']['name'];
$lang['theme']['mod_title']="Modification des informations du ".$lang['theme']['name'];


/*	nommage rubrique module
 *  	*/
$lang['theme']['add']= "Ajout d'un ".$lang['theme']['name'];
$lang['theme']['mod']= "Modification d'un ".$lang['theme']['name'];
$lang['theme']['sup']= "Suppression d'un ".$lang['theme']['name'];
$lang['theme']['det']= "Détails du ".$lang['theme']['name'];
$lang['theme']['list']= "Consultation des thèmes";
$lang['sdtheme']['det']= "Détails du thème principal";

/*	nommage élément rubrique
 *  	*/
$lang['theme']['is_root']="Est une finalité ?";
$lang['theme']['denomination']="Dénomination du ".$lang['theme']['name'];
$lang['theme']['sdtheme']="Finalité";
$lang['theme']['photouri']="Visuel associé au ".$lang['theme']['name'];
$lang['theme']['statut']="Statut du ".$lang['theme']['name'];

$lang['theme']['description']="Description du ".$lang['theme']['name'];
$lang['theme']['description_all']="Description commune à l'ensemble des modules.";
$lang['theme']['desc_all']="Description du thème (commune).";
$lang['theme']['description_det']="Description du ".$lang['theme']['name']." par module.";
$lang['theme']['desc_det_project']="Projets  (description)";
$lang['theme']['desc_det_dashboard']="Tableau de bord  (description)";
$lang['theme']['desc_det_publication']="Publications (description)";
$lang['theme']['desc_det_news']="Actualité (description)";
$lang['theme']['desc_det_workshop']="Groupe de travail (description)";
$lang['theme']['desc_det_forum']="Forum (description)";

/*	nommage rubrique sup
 *  	*/
$lang['theme']['sup_massd']= "Supprimer les ressources attachées à ce thème";
$lang['theme']['sup_massm']= "Attacher les ressources à un autre thème";
$lang['theme']['sup_transfert']= "Thème de transfert";

/*	nommage quickbox
 *  	*/
$lang['theme']['qb_titleadd']=" derniers ajouts effectués";
$lang['theme']['qb_titlemod']=" dernières modifications effectuées";
$lang['theme']['qb_titlesup']=" dernières suppressions effectuées";

/*	messages
 *  	*/
$lang['theme']['object_notdenomination']="Vous devez impérativement entrer un nom de thème.";
$lang['theme']['object_notSDtheme']="Vous devez impérativement associer le thème à une thèmatique Développement Durable.";
$lang['theme']['object_notdesc_completed']="Vous devez impérativement renseigner les descriptions pour chaque module.";
$lang['theme']['object_notstatus']="Vous devez impérativement préciser le statut du thème.";
$lang['theme']['sup_nomethod']="Vous devez impérativement choisir une méthode de suppression!";
$lang['theme']['sup_notheme']="Vous devez impérativement choisir un thème de transfert!";
$lang['theme']['sup_mass_delete']="Attention la suppression de ce thème induira la suppression de ses ressources associées.";
$lang['theme']['sup_mass_modify']="En choisissant un transfert, toutes les ressources associées au thème que vous souhaitez supprimer seront associées au nouveau thème choisi.";

/*	rubrique d'aide
 *  	*/
$lang['theme']['help_add1']="Pour ajouter un thème, vous devez entrer chacun de ses paramètres dans le formulaire ci-dessus";
$lang['theme']['help_add2']="Vous devez impérativement associer un thème général au thème en cours de création";
$lang['theme']['help_add3']="Après avoir validé le formulaire d'ajout, vérifiez les paramètres d'ajout dans le récapitulatif";
$lang['theme']['help_add4']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour les modifier";


$lang['theme']['help_list1']="Pour afficher un thème en détails, cliquez sur le nom de celui-ci";
$lang['theme']['help_list2']="Vous pouvez supprimer un thème en cliquant sur l'icône de suppression qui lui est associée";
$lang['theme']['help_list3']="Vous pouvez modifier un thème en cliquant sur l'icône de modification qui lui est associée";
$lang['theme']['help_list4']="Pour ajouter un thème, cliquez sur le lien \"ajouter un thème\" dans la barre de titre";
$lang['theme']['help_list5']="Vous pouvez faire une recherche de thème à tout moment en cliquant sur 'recherche'";


$lang['theme']['help_mod1']="Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus";
$lang['theme']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif";
$lang['theme']['help_mod3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour modifier à nouveau les données";


$lang['theme']['help_det1']="Pour afficher le détail du thème général associé au thème détaillé, cliquez sur le nom de celui-ci";
$lang['theme']['help_det2']="Vous pouvez supprimer ce thème en cliquant sur l'icône de suppression qui lui est associée";
$lang['theme']['help_det3']="Vous pouvez modifier ce thème en cliquant sur l'icône de modification qui lui est associée";
$lang['sdtheme']['help_det1']="Le thème actuel est un thème racine (composante du Développement Durable). Il n'est, par conséquent, ni éditable ni supprimable.";


$lang['theme']['help_sup1']="Vous devez impérativement choisir une méthode de suppression pour supprimer un thème";
$lang['theme']['help_sup2']="Pour des raisons de sécurité, vous devez recopier le texte-image dans le champ prévu à cet effet afin de valider la suppression";
$lang['theme']['help_sup3']="Attention la suppression du thème séléctionné entrainera de nombreux changements dans l'ensemble des modules, cette suppression est réservée aux administrateurs avertis";

?>

==> dl.php?src=linea21_1_8.zip: linea21/languages/fr/lang_theme.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	confirmation
 *  	*/
$lang['theme']['name']="thème";
$lang['theme']['confirm_add'] = "Ajout du thème réalisé avec succès\n";
$lang['theme']['confirm_mod'] = "Modification du thème réalisée avec succès\n";
$lang['theme']['confirm_sup'] ="Suppression du thème réalisée avec succès\n";

/*	nommage rubrique add / mod /det
 *  	*/
$lang['theme']['add_title']="Saisie des informations du nouveau ".$lang['theme']['name'];
$lang['theme']['mod_title']="Modification des informations du ".$lang['theme']['name'];


/*	nommage rubrique module
 *  	*/
$lang['theme']['add']= "Ajout d'un ".$lang['theme']['name'];
$lang['theme']['mod']= "Modification d'un ".$lang['theme']['name'];
$lang['theme']['sup']= "Suppression d'un ".$lang['theme']['name'];
$lang['theme']['det']= "Détails du ".$lang['theme']['name'];
$lang['theme']['list']= "Consultation des thèmes";
$lang['sdtheme']['det']= "Détails du thème principal";

/*	nommage élément rubrique
 *  	*/
$lang['theme']['is_root']="Est une finalité ?";
$lang['theme']['denomination']="Dénomination du ".$lang['theme']['name'];
$lang['theme']['sdtheme']="Finalité";
$lang['theme']['photouri']="Visuel associé au ".$lang['theme']['name'];
$lang['theme']['statut']="Statut du ".$lang['theme']['name'];

$lang['theme']['description']="Description du ".$lang['theme']['name'];
$lang['theme']['description_all']="Description commune à l'ensemble des modules";
$lang['theme']['desc_all']="Description du thème (commune)";
$lang['theme']['description_det']="Description du ".$lang['theme']['name']." par module";
$lang['theme']['desc_det_project']="Projets  (description)";
$lang['theme']['desc_det_dashboard']="Tableau de bord  (description)";
$lang['theme']['desc_det_publication']="Publications (description)";
$lang['theme']['desc_det_news']="Actualité (description)";
$lang['theme']['desc_det_workshop']="Groupe de travail (description)";
$lang['theme']['desc_det_forum']="Forum (description)";

/*	nommage rubrique sup
 *  	*/
$lang['theme']['sup_massd']= "Supprimer les ressources attachées à ce thème";
$lang['theme']['sup_massm']= "Attacher les ressources à un autre thème";
$lang['theme']['sup_transfert']= "Thème de transfert";

/*	nommage quickbox
 *  	*/
$lang['theme']['qb_titleadd']=" derniers ajouts effectués";
$lang['theme']['qb_titlemod']=" dernières modifications effectuées";
$lang['theme']['qb_titlesup']=" dernières suppressions effectuées";

/*	messages
 *  	*/
$lang['theme']['object_notdenomination']="Vous devez impérativement entrer un nom de thème.";
$lang['theme']['object_notSDtheme']="Vous devez impérativement associer le thème à une thèmatique Développement Durable.";
$lang['theme']['object_notdesc_completed']="Vous devez impérativement renseigner les descriptions pour chaque module.";
$lang['theme']['object_notstatus']="Vous devez impérativement préciser le statut du thème.";
$lang['theme']['sup_nomethod']="Vous devez impérativement choisir une méthode de suppression!";
$lang['theme']['sup_notheme']="Vous devez impérativement choisir un thème de transfert!";
$lang['theme']['sup_mass_delete']="Attention la suppression de ce thème induira la suppression de ses ressources associées.";
$lang['theme']['sup_mass_modify']="En choisissant un transfert, toutes les ressources associées au thème que vous souhaitez supprimer seront associées au nouveau thème choisi.";

/*	rubrique d'aide
 *  	*/
$lang['theme']['help_add1']="Pour ajouter un thème, vous devez entrer chacun de ses paramètres dans le formulaire ci-dessus";
$lang['theme']['help_add2']="Vous devez impérativement associer un thème général au thème en cours de création";
$lang['theme']['help_add3']="Après avoir validé le formulaire d'ajout, vérifiez les paramètres d'ajout dans le récapitulatif";
$lang['theme']['help_add4']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour les modifier";


$lang['theme']['help_list1']="Pour afficher un thème en détails, cliquez sur le nom de celui-ci";
$lang['theme']['help_list2']="Vous pouvez supprimer un thème en cliquant sur l'icône de suppression qui lui est associée";
$lang['theme']['help_list3']="Vous pouvez modifier un thème en cliquant sur l'icône de modification qui lui est associée";
$lang['theme']['help_list4']="Pour ajouter un thème, cliquez sur le lien \"ajouter un thème\" dans la barre de titre";
$lang['theme']['help_list5']="Vous pouvez faire une recherche de thème à tout moment en cliquant sur 'recherche'";


$lang['theme']['help_mod1']="Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus";
$lang['theme']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif";
$lang['theme']['help_mod3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour modifier à nouveau les données";


$lang['theme']['help_det1']="Pour afficher le détail du thème général associé au thème détaillé, cliquez sur le nom de celui-ci";
$lang['theme']['help_det2']="Vous pouvez supprimer ce thème en cliquant sur l'icône de suppression qui lui est associée";
$lang['theme']['help_det3']="Vous pouvez modifier ce thème en cliquant sur l'icône de modification qui lui est associée";
$lang['sdtheme']['help_det1']="Le thème actuel est un thème racine (composante du Développement Durable). Il n'est, par conséquent, ni éditable ni supprimable.";


$lang['theme']['help_sup1']="Vous devez impérativement choisir une méthode de suppression pour supprimer un thème";
$lang['theme']['help_sup2']="Pour des raisons de sécurité, vous devez recopier le texte-image dans le champ prévu à cet effet afin de valider la suppression";
$lang['theme']['help_sup3']="Attention la suppression du thème séléctionné entrainera de nombreux changements dans l'ensemble des modules, cette suppression est réservée aux administrateurs avertis";

?>
